Class: Google::Apis::PubsubliteV1::PubsubLiteService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::PubsubliteV1::PubsubLiteService
- Defined in:
- lib/google/apis/pubsublite_v1/service.rb
Overview
Pub/Sub Lite API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://pubsublite.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#commit_subscription_cursor(subscription, commit_cursor_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::CommitCursorResponse
Updates the committed cursor.
-
#compute_topic_head_cursor(topic, compute_head_cursor_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ComputeHeadCursorResponse
Compute the head cursor for the partition.
-
#compute_topic_message_stats(topic, compute_message_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ComputeMessageStatsResponse
Compute statistics about a range of messages in a given topic and partition.
-
#compute_topic_time_cursor(topic, compute_time_cursor_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ComputeTimeCursorResponse
Compute the corresponding cursor for a publish or event time in a topic partition.
-
#create_admin_project_location_reservation(parent, reservation_object = nil, reservation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Reservation
Creates a new reservation.
-
#create_admin_project_location_subscription(parent, subscription_object = nil, skip_backlog: nil, subscription_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Subscription
Creates a new subscription.
-
#create_admin_project_location_topic(parent, topic_object = nil, topic_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Topic
Creates a new topic.
-
#delete_admin_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Empty
Deletes a long-running operation.
-
#delete_admin_project_location_reservation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Empty
Deletes the specified reservation.
-
#delete_admin_project_location_subscription(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Empty
Deletes the specified subscription.
-
#delete_admin_project_location_topic(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Empty
Deletes the specified topic.
-
#get_admin_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Operation
Gets the latest state of a long-running operation.
-
#get_admin_project_location_reservation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Reservation
Returns the reservation configuration.
-
#get_admin_project_location_subscription(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Subscription
Returns the subscription configuration.
-
#get_admin_project_location_topic(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Topic
Returns the topic configuration.
-
#get_admin_project_location_topic_partitions(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::TopicPartitions
Returns the partition information for the requested topic.
-
#initialize ⇒ PubsubLiteService
constructor
A new instance of PubsubLiteService.
-
#list_admin_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_admin_project_location_reservation_topics(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListReservationTopicsResponse
Lists the topics attached to the specified reservation.
-
#list_admin_project_location_reservations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListReservationsResponse
Returns the list of reservations for the given project.
-
#list_admin_project_location_subscriptions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListSubscriptionsResponse
Returns the list of subscriptions for the given project.
-
#list_admin_project_location_topic_subscriptions(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListTopicSubscriptionsResponse
Lists the subscriptions attached to the specified topic.
-
#list_admin_project_location_topics(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListTopicsResponse
Returns the list of topics for the given project.
-
#list_cursor_project_location_subscription_cursors(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListPartitionCursorsResponse
Returns all committed cursor information for a subscription.
-
#patch_admin_project_location_reservation(name, reservation_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Reservation
Updates properties of the specified reservation.
-
#patch_admin_project_location_subscription(name, subscription_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Subscription
Updates properties of the specified subscription.
-
#patch_admin_project_location_topic(name, topic_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Topic
Updates properties of the specified topic.
-
#seek_subscription(name, seek_subscription_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Operation
Performs an out-of-band seek for a subscription to a specified target, which may be timestamps or named positions within the message backlog.
Constructor Details
#initialize ⇒ PubsubLiteService
Returns a new instance of PubsubLiteService.
47 48 49 50 51 52 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-pubsublite_v1', client_version: Google::Apis::PubsubliteV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 82 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/admin/{+name}:cancel', ) command.request_representation = Google::Apis::PubsubliteV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::PubsubliteV1::Empty::Representation command.response_class = Google::Apis::PubsubliteV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#commit_subscription_cursor(subscription, commit_cursor_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::CommitCursorResponse
Updates the committed cursor.
926 927 928 929 930 931 932 933 934 935 936 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 926 def commit_subscription_cursor(subscription, commit_cursor_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/cursor/{+subscription}:commitCursor', ) command.request_representation = Google::Apis::PubsubliteV1::CommitCursorRequest::Representation command.request_object = commit_cursor_request_object command.response_representation = Google::Apis::PubsubliteV1::CommitCursorResponse::Representation command.response_class = Google::Apis::PubsubliteV1::CommitCursorResponse command.params['subscription'] = subscription unless subscription.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#compute_topic_head_cursor(topic, compute_head_cursor_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ComputeHeadCursorResponse
Compute the head cursor for the partition. The head cursor's offset is guaranteed to be less than or equal to all messages which have not yet been acknowledged as published, and greater than the offset of any message whose publish has already been acknowledged. It is zero if there have never been messages in the partition.
1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 1005 def compute_topic_head_cursor(topic, compute_head_cursor_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/topicStats/{+topic}:computeHeadCursor', ) command.request_representation = Google::Apis::PubsubliteV1::ComputeHeadCursorRequest::Representation command.request_object = compute_head_cursor_request_object command.response_representation = Google::Apis::PubsubliteV1::ComputeHeadCursorResponse::Representation command.response_class = Google::Apis::PubsubliteV1::ComputeHeadCursorResponse command.params['topic'] = topic unless topic.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#compute_topic_message_stats(topic, compute_message_stats_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ComputeMessageStatsResponse
Compute statistics about a range of messages in a given topic and partition.
1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 1038 def (topic, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/topicStats/{+topic}:computeMessageStats', ) command.request_representation = Google::Apis::PubsubliteV1::ComputeMessageStatsRequest::Representation command.request_object = command.response_representation = Google::Apis::PubsubliteV1::ComputeMessageStatsResponse::Representation command.response_class = Google::Apis::PubsubliteV1::ComputeMessageStatsResponse command.params['topic'] = topic unless topic.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#compute_topic_time_cursor(topic, compute_time_cursor_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ComputeTimeCursorResponse
Compute the corresponding cursor for a publish or event time in a topic partition.
1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 1072 def compute_topic_time_cursor(topic, compute_time_cursor_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/topicStats/{+topic}:computeTimeCursor', ) command.request_representation = Google::Apis::PubsubliteV1::ComputeTimeCursorRequest::Representation command.request_object = compute_time_cursor_request_object command.response_representation = Google::Apis::PubsubliteV1::ComputeTimeCursorResponse::Representation command.response_class = Google::Apis::PubsubliteV1::ComputeTimeCursorResponse command.params['topic'] = topic unless topic.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_admin_project_location_reservation(parent, reservation_object = nil, reservation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Reservation
Creates a new reservation.
233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 233 def create_admin_project_location_reservation(parent, reservation_object = nil, reservation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/admin/{+parent}/reservations', ) command.request_representation = Google::Apis::PubsubliteV1::Reservation::Representation command.request_object = reservation_object command.response_representation = Google::Apis::PubsubliteV1::Reservation::Representation command.response_class = Google::Apis::PubsubliteV1::Reservation command.params['parent'] = parent unless parent.nil? command.query['reservationId'] = reservation_id unless reservation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_admin_project_location_subscription(parent, subscription_object = nil, skip_backlog: nil, subscription_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Subscription
Creates a new subscription.
459 460 461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 459 def create_admin_project_location_subscription(parent, subscription_object = nil, skip_backlog: nil, subscription_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/admin/{+parent}/subscriptions', ) command.request_representation = Google::Apis::PubsubliteV1::Subscription::Representation command.request_object = subscription_object command.response_representation = Google::Apis::PubsubliteV1::Subscription::Representation command.response_class = Google::Apis::PubsubliteV1::Subscription command.params['parent'] = parent unless parent.nil? command.query['skipBacklog'] = skip_backlog unless skip_backlog.nil? command.query['subscriptionId'] = subscription_id unless subscription_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_admin_project_location_topic(parent, topic_object = nil, topic_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Topic
Creates a new topic.
684 685 686 687 688 689 690 691 692 693 694 695 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 684 def create_admin_project_location_topic(parent, topic_object = nil, topic_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/admin/{+parent}/topics', ) command.request_representation = Google::Apis::PubsubliteV1::Topic::Representation command.request_object = topic_object command.response_representation = Google::Apis::PubsubliteV1::Topic::Representation command.response_class = Google::Apis::PubsubliteV1::Topic command.params['parent'] = parent unless parent.nil? command.query['topicId'] = topic_id unless topic_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_admin_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
117 118 119 120 121 122 123 124 125 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 117 def delete_admin_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/admin/{+name}', ) command.response_representation = Google::Apis::PubsubliteV1::Empty::Representation command.response_class = Google::Apis::PubsubliteV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_admin_project_location_reservation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Empty
Deletes the specified reservation.
267 268 269 270 271 272 273 274 275 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 267 def delete_admin_project_location_reservation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/admin/{+name}', ) command.response_representation = Google::Apis::PubsubliteV1::Empty::Representation command.response_class = Google::Apis::PubsubliteV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_admin_project_location_subscription(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Empty
Deletes the specified subscription.
493 494 495 496 497 498 499 500 501 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 493 def delete_admin_project_location_subscription(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/admin/{+name}', ) command.response_representation = Google::Apis::PubsubliteV1::Empty::Representation command.response_class = Google::Apis::PubsubliteV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_admin_project_location_topic(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Empty
Deletes the specified topic.
717 718 719 720 721 722 723 724 725 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 717 def delete_admin_project_location_topic(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/admin/{+name}', ) command.response_representation = Google::Apis::PubsubliteV1::Empty::Representation command.response_class = Google::Apis::PubsubliteV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_admin_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
148 149 150 151 152 153 154 155 156 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 148 def get_admin_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+name}', ) command.response_representation = Google::Apis::PubsubliteV1::Operation::Representation command.response_class = Google::Apis::PubsubliteV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_admin_project_location_reservation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Reservation
Returns the reservation configuration.
299 300 301 302 303 304 305 306 307 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 299 def get_admin_project_location_reservation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+name}', ) command.response_representation = Google::Apis::PubsubliteV1::Reservation::Representation command.response_class = Google::Apis::PubsubliteV1::Reservation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_admin_project_location_subscription(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Subscription
Returns the subscription configuration.
523 524 525 526 527 528 529 530 531 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 523 def get_admin_project_location_subscription(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+name}', ) command.response_representation = Google::Apis::PubsubliteV1::Subscription::Representation command.response_class = Google::Apis::PubsubliteV1::Subscription command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_admin_project_location_topic(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Topic
Returns the topic configuration.
747 748 749 750 751 752 753 754 755 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 747 def get_admin_project_location_topic(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+name}', ) command.response_representation = Google::Apis::PubsubliteV1::Topic::Representation command.response_class = Google::Apis::PubsubliteV1::Topic command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_admin_project_location_topic_partitions(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::TopicPartitions
Returns the partition information for the requested topic.
777 778 779 780 781 782 783 784 785 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 777 def get_admin_project_location_topic_partitions(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+name}/partitions', ) command.response_representation = Google::Apis::PubsubliteV1::TopicPartitions::Representation command.response_class = Google::Apis::PubsubliteV1::TopicPartitions command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_admin_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 193 def list_admin_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+name}/operations', ) command.response_representation = Google::Apis::PubsubliteV1::ListOperationsResponse::Representation command.response_class = Google::Apis::PubsubliteV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_admin_project_location_reservation_topics(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListReservationTopicsResponse
Lists the topics attached to the specified reservation.
417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 417 def list_admin_project_location_reservation_topics(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+name}/topics', ) command.response_representation = Google::Apis::PubsubliteV1::ListReservationTopicsResponse::Representation command.response_class = Google::Apis::PubsubliteV1::ListReservationTopicsResponse command.params['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_admin_project_location_reservations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListReservationsResponse
Returns the list of reservations for the given project.
339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 339 def list_admin_project_location_reservations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+parent}/reservations', ) command.response_representation = Google::Apis::PubsubliteV1::ListReservationsResponse::Representation command.response_class = Google::Apis::PubsubliteV1::ListReservationsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_admin_project_location_subscriptions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListSubscriptionsResponse
Returns the list of subscriptions for the given project.
563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 563 def list_admin_project_location_subscriptions(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+parent}/subscriptions', ) command.response_representation = Google::Apis::PubsubliteV1::ListSubscriptionsResponse::Representation command.response_class = Google::Apis::PubsubliteV1::ListSubscriptionsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_admin_project_location_topic_subscriptions(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListTopicSubscriptionsResponse
Lists the subscriptions attached to the specified topic.
893 894 895 896 897 898 899 900 901 902 903 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 893 def list_admin_project_location_topic_subscriptions(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+name}/subscriptions', ) command.response_representation = Google::Apis::PubsubliteV1::ListTopicSubscriptionsResponse::Representation command.response_class = Google::Apis::PubsubliteV1::ListTopicSubscriptionsResponse command.params['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_admin_project_location_topics(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListTopicsResponse
Returns the list of topics for the given project.
815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 815 def list_admin_project_location_topics(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/admin/{+parent}/topics', ) command.response_representation = Google::Apis::PubsubliteV1::ListTopicsResponse::Representation command.response_class = Google::Apis::PubsubliteV1::ListTopicsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_cursor_project_location_subscription_cursors(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::ListPartitionCursorsResponse
Returns all committed cursor information for a subscription.
968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 968 def list_cursor_project_location_subscription_cursors(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/cursor/{+parent}/cursors', ) command.response_representation = Google::Apis::PubsubliteV1::ListPartitionCursorsResponse::Representation command.response_class = Google::Apis::PubsubliteV1::ListPartitionCursorsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_admin_project_location_reservation(name, reservation_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Reservation
Updates properties of the specified reservation.
375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 375 def patch_admin_project_location_reservation(name, reservation_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/admin/{+name}', ) command.request_representation = Google::Apis::PubsubliteV1::Reservation::Representation command.request_object = reservation_object command.response_representation = Google::Apis::PubsubliteV1::Reservation::Representation command.response_class = Google::Apis::PubsubliteV1::Reservation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_admin_project_location_subscription(name, subscription_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Subscription
Updates properties of the specified subscription.
599 600 601 602 603 604 605 606 607 608 609 610 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 599 def patch_admin_project_location_subscription(name, subscription_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/admin/{+name}', ) command.request_representation = Google::Apis::PubsubliteV1::Subscription::Representation command.request_object = subscription_object command.response_representation = Google::Apis::PubsubliteV1::Subscription::Representation command.response_class = Google::Apis::PubsubliteV1::Subscription command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_admin_project_location_topic(name, topic_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Topic
Updates properties of the specified topic.
851 852 853 854 855 856 857 858 859 860 861 862 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 851 def patch_admin_project_location_topic(name, topic_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/admin/{+name}', ) command.request_representation = Google::Apis::PubsubliteV1::Topic::Representation command.request_object = topic_object command.response_representation = Google::Apis::PubsubliteV1::Topic::Representation command.response_class = Google::Apis::PubsubliteV1::Topic command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#seek_subscription(name, seek_subscription_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PubsubliteV1::Operation
Performs an out-of-band seek for a subscription to a specified target, which may be timestamps or named positions within the message backlog. Seek translates these targets to cursors for each partition and orchestrates subscribers to start consuming messages from these seek cursors. If an operation is returned, the seek has been registered and subscribers will eventually receive messages from the seek cursors (i.e. eventual consistency), as long as they are using a minimum supported client library version and not a system that tracks cursors independently of Pub/Sub Lite (e.g. Apache Beam, Dataflow, Spark). The seek operation will fail for unsupported clients. If clients would like to know when subscribers react to the seek (or not), they can poll the operation. The seek operation will succeed and complete once subscribers are ready to receive messages from the seek cursors for all partitions of the topic. This means that the seek operation will not complete until all subscribers come online. If the previous seek operation has not yet completed, it will be aborted and the new invocation of seek will supersede it.
647 648 649 650 651 652 653 654 655 656 657 |
# File 'lib/google/apis/pubsublite_v1/service.rb', line 647 def seek_subscription(name, seek_subscription_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/admin/{+name}:seek', ) command.request_representation = Google::Apis::PubsubliteV1::SeekSubscriptionRequest::Representation command.request_object = seek_subscription_request_object command.response_representation = Google::Apis::PubsubliteV1::Operation::Representation command.response_class = Google::Apis::PubsubliteV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |