Class: Google::Apis::PubsubliteV1::Subscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pubsublite_v1/classes.rb,
lib/google/apis/pubsublite_v1/representations.rb,
lib/google/apis/pubsublite_v1/representations.rb

Overview

Metadata about a subscription resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subscription

Returns a new instance of Subscription.



925
926
927
# File 'lib/google/apis/pubsublite_v1/classes.rb', line 925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delivery_configGoogle::Apis::PubsubliteV1::DeliveryConfig

The settings for a subscription's message delivery. Corresponds to the JSON property deliveryConfig



905
906
907
# File 'lib/google/apis/pubsublite_v1/classes.rb', line 905

def delivery_config
  @delivery_config
end

#export_configGoogle::Apis::PubsubliteV1::ExportConfig

Configuration for a Pub/Sub Lite subscription that writes messages to a destination. User subscriber clients must not connect to this subscription. Corresponds to the JSON property exportConfig



911
912
913
# File 'lib/google/apis/pubsublite_v1/classes.rb', line 911

def export_config
  @export_config
end

#nameString

The name of the subscription. Structured like: projects/project_number/ locations/location/subscriptions/subscription_id Corresponds to the JSON property name

Returns:

  • (String)


917
918
919
# File 'lib/google/apis/pubsublite_v1/classes.rb', line 917

def name
  @name
end

#topicString

The name of the topic this subscription is attached to. Structured like: projects/project_number/locations/location/topics/topic_id Corresponds to the JSON property topic

Returns:

  • (String)


923
924
925
# File 'lib/google/apis/pubsublite_v1/classes.rb', line 923

def topic
  @topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



930
931
932
933
934
935
# File 'lib/google/apis/pubsublite_v1/classes.rb', line 930

def update!(**args)
  @delivery_config = args[:delivery_config] if args.key?(:delivery_config)
  @export_config = args[:export_config] if args.key?(:export_config)
  @name = args[:name] if args.key?(:name)
  @topic = args[:topic] if args.key?(:topic)
end